@@ -26,7 +26,6 @@ def run(args: List[str], cwd: Path, out: TextIO):  # pylint: disable=C0116
 
 
 def main(args: List[str]) -> int:  # pylint: disable=C0116
-
     parser = argparse.ArgumentParser(description=__doc__)
     parser.add_argument(
         "--build-shared-libs",
@@ -76,10 +75,10 @@ def main(args: List[str]) -> int:  # pylint: disable=C0116
                 options.platform,
                 f"-DBUILD_SHARED_LIBS={options.build_shared_libs}",
                 "-Dwith_cxx_api=ON",
-                "-Denable_ltdl=ON",
-                "-Dwith_expat=ON",
-                "-Dwith_gvedit=OFF",
-                "-Dwith_zlib=ON",
+                "-DENABLE_LTDL=ON",
+                "-DWITH_EXPAT=ON",
+                "-DWITH_GVEDIT=OFF",
+                "-DWITH_ZLIB=ON",
                 "--warn-uninitialized",
                 "-Werror=dev",
                 "..",
