@@ -14,8 +14,8 @@
 #include "gui.h"
 #include "viewport.h"
 #include "gltemplate.h"
-#include <cgraph/exit.h>
 #include <glcomp/glutils.h>
+#include <util/exit.h>
 #include "glexpose.h"
 #include "glmotion.h"
 
@@ -116,7 +116,7 @@ static gboolean configure_event(GtkWidget *widget, GdkEventConfigure *event,
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
     if (widget->allocation.width > 1)
-	init_arcBall(view->arcball, (float)view->w, (float)view->h);
+	init_arcBall(view->arcball, view->w, view->h);
 
     if (view->w > view->h) {
 	aspect = (float) view->w / (float) view->h;
@@ -184,7 +184,10 @@ static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event, voi
 
     begin_x = (float) event->x;
     begin_y = (float) event->y;
-    view->widgets->common.functions.mousedown((glCompObj*)view->widgets, (float)event->x, (float)event->y, getGlCompMouseType(event->button));
+    view->widgets->base.common.functions.mousedown(&view->widgets->base,
+                                                   (float)event->x,
+                                                   (float)event->y,
+                                                   getGlCompMouseType(event->button));
     if (event->button == 1)	//left click
 	appmouse_left_click_down(view,(int) event->x,(int) event->y);
 
@@ -210,8 +213,10 @@ static gboolean button_release_event(GtkWidget *widget, GdkEventButton *event,
 
     if (view->widgets == 0) return FALSE;
     view->arcball->isDragging = 0;
-    view->widgets->common.functions.mouseup((glCompObj*)view->widgets, (float)event->x, (float)event->y, getGlCompMouseType(event->button));
-
+    view->widgets->base.common.functions.mouseup(&view->widgets->base,
+                                                 (float)event->x,
+                                                 (float)event->y,
+                                                 getGlCompMouseType(event->button));
 
     if (event->button == 1)	//left click release
 	appmouse_left_click_up(view,(int) event->x,(int) event->y);
@@ -282,7 +287,7 @@ static gboolean motion_notify_event(GtkWidget *widget, GdkEventMotion *event,
 
     bool redraw = false;
     if (view->widgets)
-	view->widgets->common.functions.mouseover((glCompObj*)view->widgets, x, y);
+	view->widgets->base.common.functions.mouseover(&view->widgets->base, x, y);
 
     dx = x - begin_x;
     dy = y - begin_y;
@@ -306,7 +311,7 @@ static gboolean motion_notify_event(GtkWidget *widget, GdkEventMotion *event,
 	appmouse_middle_drag(view,(int)event->x,(int)event->y);
 	redraw = true;
     }
-    if(view->Topview->sel.selPoly.cnt > 0)
+    if (!glCompPoly_is_empty(&view->Topview->sel.selPoly))
 	redraw = true;
 
     begin_x = x;
