@@ -13,14 +13,13 @@
 #include <assert.h>
 #include "viewport.h"
 #include "draw.h"
-#include <cgraph/alloc.h>
 #include <common/color.h>
 #include <glade/glade.h>
 #include "gui.h"
 #include <limits.h>
 #include "menucallbacks.h"
-#include <stddef.h>
 #include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
 #include "glcompui.h"
 #include "gltemplate.h"
@@ -29,9 +28,9 @@
 #include "arcball.h"
 #include "hotkeymap.h"
 #include "topviewfuncs.h"
-#include <cgraph/exit.h>
-#include <cgraph/strcasecmp.h>
-
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/strcasecmp.h>
 
 static colorschemaset *create_color_theme(int themeid);
 
@@ -87,7 +86,6 @@ char *get_attribute_value(char *attr, ViewInfo *vi, Agraph_t *g) {
 
 void set_viewport_settings_from_template(ViewInfo *vi, Agraph_t *g) {
     gvcolor_t cl;
-    char *buf;
     colorxlate(get_attribute_value("bordercolor", vi, g), &cl,
 	       RGBA_DOUBLE);
     vi->borderColor.R = (float)cl.u.RGBA[0];
@@ -99,7 +97,7 @@ void set_viewport_settings_from_template(ViewInfo *vi, Agraph_t *g) {
 
     vi->bdVisible = atoi(get_attribute_value("bordervisible", vi, g));
 
-    buf = get_attribute_value("gridcolor", vi, g);
+    const char *buf = get_attribute_value("gridcolor", vi, g);
     colorxlate(buf, &cl, RGBA_DOUBLE);
     vi->gridColor.R = (float)cl.u.RGBA[0];
     vi->gridColor.G = (float)cl.u.RGBA[1];
@@ -170,8 +168,7 @@ void set_viewport_settings_from_template(ViewInfo *vi, Agraph_t *g) {
 	glClearColor(vi->bgColor.R, vi->bgColor.G, vi->bgColor.B, vi->bgColor.A);	//background color
 }
 
-static gboolean gl_main_expose(gpointer data)
-{
+static gboolean gl_main_expose(void *data) {
     (void)data;
 
     if (view->activeGraph >= 0) {
@@ -185,13 +182,12 @@ static gboolean gl_main_expose(gpointer data)
 static void get_data_dir(void)
 {
     free(view->template_file);
-    view->template_file = gv_strdup(smyrnaPath("template.dot"));
+    view->template_file = smyrnaPath("template.dot");
 }
 
 void init_viewport(ViewInfo *vi) {
     FILE *input_file = NULL;
     FILE *input_file2 = NULL;
-    static char* path;
     get_data_dir();
     input_file = fopen(vi->template_file, "rb");
     if (!input_file) {
@@ -209,18 +205,24 @@ void init_viewport(ViewInfo *vi) {
 		vi->template_file);
 	graphviz_exit(-1);
     }
-    if (!path)
-	path = smyrnaPath("attr_widgets.dot");
-    input_file2 = fopen(path, "rb");
+    {
+	char *path = smyrnaPath("attr_widgets.dot");
+	input_file2 = fopen(path, "rb");
+	free(path);
+    }
     if (!input_file2) {
-	fprintf(stderr,	"default attributes template graph file \"%s\" not found\n",smyrnaPath("attr_widgets.dot"));
+	char *attrwidgets = smyrnaPath("attr_widgets.dot");
+	fprintf(stderr,	"default attributes template graph file \"%s\" not found\n", attrwidgets);
+	free(attrwidgets);
 	graphviz_exit(-1);
 
     }
     vi->systemGraphs.attrs_widgets = agread(input_file2, NULL);
     fclose (input_file2);
     if (!vi->systemGraphs.attrs_widgets) {
-	fprintf(stderr,"could not load default attribute widgets graph file \"%s\"\n",smyrnaPath("attr_widgets.dot"));
+	char *attrwidgets = smyrnaPath("attr_widgets.dot");
+	fprintf(stderr,"could not load default attribute widgets graph file \"%s\"\n", attrwidgets);
+	free(attrwidgets);
 	graphviz_exit(-1);
     }
     //init graphs
@@ -311,9 +313,6 @@ void init_viewport(ViewInfo *vi) {
     vi->arcball = gv_alloc(sizeof(ArcBall_t));
     vi->keymap.down=0;
     load_mouse_actions(vi);
-    vi->refresh.color=1;
-    vi->refresh.pos=1;
-    vi->refresh.selection=1;
     if(vi->guiMode!=GUI_FULLSCREEN)
 	vi->guiMode=GUI_WINDOWED;
 
@@ -411,9 +410,6 @@ graphRecord (Agraph_t* g)
 void refreshViewport(void)
 {
     Agraph_t *graph = view->g[view->activeGraph];
-    view->refresh.color=1;
-    view->refresh.pos=1;
-    view->refresh.selection=1;
     load_settings_from_graph();
 
     if(view->guiMode!=GUI_FULLSCREEN)
