@@ -23,16 +23,16 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/ingraphs.h>
 #include <cgraph/list.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/unreachable.h>
-#include <cgraph/exit.h>
 #include <common/render.h>
 #include <common/utils.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/prisize_t.h>
+#include <util/unreachable.h>
 
 typedef struct {
     Agrec_t h;
