@@ -18,12 +18,12 @@
 
 #include <math.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <common/render.h>
-#include <cgraph/unreachable.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
+#include <util/alloc.h>
+#include <util/unreachable.h>
 
 #ifdef DEBUG
 static int debugleveln(edge_t* e, int i)
