@@ -15,7 +15,6 @@
 
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
 #include <common/boxes.h>
 #include <dotgen/dot.h>
@@ -24,6 +23,7 @@
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
+#include <util/alloc.h>
 
 #ifdef ORTHO
 #include <ortho/ortho.h>
@@ -1932,6 +1932,7 @@ static void make_regular_edge(graph_t *g, spline_info_t *sp, path *P,
     /* make copies of the spline points, one per multi-edge */
 
     if (cnt == 1) {
+	points_sync(&pointfs);
 	clip_and_install(fe, hn, points_front(&pointfs), points_size(&pointfs),
 	                 &sinfo);
 	points_free(&pointfs);
@@ -1944,6 +1945,7 @@ static void make_regular_edge(graph_t *g, spline_info_t *sp, path *P,
 
     for (size_t k = 0; k < points_size(&pointfs); k++)
 	points_append(&pointfs2, points_get(&pointfs, k));
+    points_sync(&pointfs2);
     clip_and_install(fe, hn, points_front(&pointfs2),
                      points_size(&pointfs2), &sinfo);
     for (unsigned j = 1; j < cnt; j++) {
@@ -1957,6 +1959,7 @@ static void make_regular_edge(graph_t *g, spline_info_t *sp, path *P,
 	points_clear(&pointfs2);
 	for (size_t k = 0; k < points_size(&pointfs); k++)
 	    points_append(&pointfs2, points_get(&pointfs, k));
+	points_sync(&pointfs2);
 	clip_and_install(e, aghead(e), points_front(&pointfs2),
 	                 points_size(&pointfs2), &sinfo);
     }
