@@ -16,16 +16,18 @@
 
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/startswith.h>
+#include <cgraph/list.h>
 #include <gvc/gvconfig.h>
 #include <stdbool.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include	<string.h>
 #include <unistd.h>
+#include <util/alloc.h>
+#include <util/exit.h>
 #include <util/gv_fopen.h>
+#include <util/startswith.h>
 
 #ifdef ENABLE_LTDL
 #ifdef HAVE_DL_ITERATE_PHDR
@@ -351,7 +353,7 @@ char * gvconfig_libdir(GVC_t * gvc)
 	    dl_iterate_phdr(line_callback, line);
 	    libdir = line;
 #else
-	    FILE* f = fopen ("/proc/self/maps", "r");
+	    FILE* f = gv_fopen("/proc/self/maps", "r");
 	    if (f) {
 		while (!feof (f)) {
 		    if (!fgets (line, sizeof (line), f))
@@ -595,7 +597,7 @@ void gvconfig(GVC_t * gvc, bool rescan)
     	    goto done;
         }
         else {
-    	    f = fopen(gvc->config_path,"r");
+    	    f = gv_fopen(gvc->config_path, "r");
     	    if (!f) {
     	        agerrorf("failed to open %s for read.\n", gvc->config_path);
 		return;
@@ -632,6 +634,8 @@ done:
 
 /* Emulating windows glob */
 
+DEFINE_LIST_WITH_DTOR(strs, char *, free)
+
 /* glob:
  * Assumes only GLOB_NOSORT flag given. That is, there is no offset,
  * and no previous call to glob.
@@ -643,9 +647,7 @@ glob (GVC_t* gvc, char* pattern, int flags, int (*errfunc)(const char *, int), g
     char* libdir;
     WIN32_FIND_DATA wfd;
     HANDLE h;
-    char** str=0;
-    int arrsize=0;
-    int cnt = 0;
+    strs_t strs = {0};
     
     pglob->gl_pathc = 0;
     pglob->gl_pathv = NULL;
@@ -654,30 +656,29 @@ glob (GVC_t* gvc, char* pattern, int flags, int (*errfunc)(const char *, int), g
     if (h == INVALID_HANDLE_VALUE) return GLOB_NOMATCH;
     libdir = gvconfig_libdir(gvc);
     do {
-      if (cnt >= arrsize-1) {
-        arrsize += 512;
-        char **new_str = realloc(str, arrsize * sizeof(char*));
-        if (!new_str) goto oom;
-        str = new_str;
+      const size_t size =
+        strlen(libdir) + strlen(DIRSEP) + strlen(wfd.cFileName) + 1;
+      char *const entry = malloc(size);
+      if (!entry) {
+        goto oom;
+      }
+      snprintf(entry, size, "%s%s%s", libdir, DIRSEP, wfd.cFileName);
+      if (strs_try_append(&strs, entry) != 0) {
+        free(entry);
+        goto oom;
       }
-      str[cnt] = malloc (strlen(libdir)+1+strlen(wfd.cFileName)+1);
-      if (!str[cnt]) goto oom;
-      strcpy(str[cnt],libdir);
-      strcat(str[cnt],DIRSEP);
-      strcat(str[cnt],wfd.cFileName);
-      cnt++;
     } while (FindNextFile (h, &wfd));
-    str[cnt] = 0;
+    if (strs_try_append(&strs, NULL) != 0) {
+      goto oom;
+    }
 
-    pglob->gl_pathc = cnt;
-    pglob->gl_pathv = realloc(str, (cnt+1)*sizeof(char*));
+    pglob->gl_pathc = strs_size(&strs);
+    pglob->gl_pathv = strs_detach(&strs);
     
     return 0;
 
 oom:
-    for (int i = 0; i < cnt; ++i)
-      free(str[i]);
-    free(str);
+    strs_free(&strs);
     return GLOB_NOSPACE;
 }
 
