@@ -10,8 +10,6 @@
 
 #include <assert.h>
 #include "config.h"
-#include <cgraph/alloc.h>
-#include <cgraph/unreachable.h>
 #include <limits.h>
 #include <math.h>
 #include <neatogen/neato.h>
@@ -21,6 +19,8 @@
 #include <neatogen/multispline.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/unreachable.h>
 
 #ifdef ORTHO
 #include <ortho/ortho.h>
@@ -105,7 +105,8 @@ typedef struct {
     edge_t *e;
 } edgeitem;
 
-static void *newitem(edgeitem *obj, Dtdisc_t *disc) {
+static void *newitem(void *p, Dtdisc_t *disc) {
+    edgeitem *obj = p;
     edgeitem *newp;
 
     (void)disc;
@@ -152,7 +153,7 @@ Dtdisc_t edgeItemDisc = {
     offsetof(edgeitem, id),
     sizeof(edgeinfo),
     offsetof(edgeitem, link),
-    (Dtmake_f) newitem,
+    newitem,
     free,
     cmpitems,
 };
