@@ -138,19 +138,15 @@ static const char *picfontname(strview_t psname) {
 }
 
 static void picptarray(GVJ_t *job, pointf *A, size_t n, int close) {
-    point p;
-
     for (size_t i = 0; i < n; i++) {
-	PF2P(A[i],p);
         if (i == 0) {
-            gvprintf(job, "move to (%d, %d)", p.x, p.y);
+            gvprintf(job, "move to (%.0f, %.0f)", A[i].x, A[i].y);
         } else {
-            gvprintf(job, "; line to (%d, %d)", p.x, p.y);
+            gvprintf(job, "; line to (%.0f, %.0f)", A[i].x, A[i].y);
         }
     }
     if (close) {
-	PF2P(A[0],p);
-        gvprintf(job, "; line to (%d, %d)", p.x, p.y);
+        gvprintf(job, "; line to (%.0f, %.0f)", A[0].x, A[0].y);
     }
     gvputs(job, "\n");
 }
@@ -344,13 +340,11 @@ static void pic_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
     (void)filled;
 
     pointf V[4];
-    point p;
 
     V[3].x = A[0].x;
     V[3].y = A[0].y;
     /* Write first point in line */
-    PF2P(A[0], p);
-    gvprintf(job, "move to (%d, %d)", p.x, p.y);
+    gvprintf(job, "move to (%.0f, %.0f)", A[0].x, A[0].y);
     /* write subsequent points */
     for (size_t i = 0; i + 3 < n; i += 3) {
         V[0] = V[3];
@@ -360,8 +354,7 @@ static void pic_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
         }
         for (int step = 1; step <= BEZIERSUBDIVISION; step++) {
             pointf pf = Bezier(V, (double)step / BEZIERSUBDIVISION, NULL, NULL);
-	    PF2P(pf, p);
-            gvprintf(job, "; spline to (%d, %d)", p.x, p.y);
+            gvprintf(job, "; spline to (%.0f, %.0f)", pf.x, pf.y);
         }
     }
 
