@@ -66,7 +66,7 @@ static void lasi_loadimage_ps(GVJ_t *job, usershape_t *us, boxf b, bool) {
       fstat(fd, &statbuf);
       us->datasize = statbuf.st_size;
 #ifdef HAVE_SYS_MMAN_H
-      us->data = mmap(0, statbuf.st_size, PROT_READ, MAP_SHARED, fd, 0);
+      us->data = mmap(0, statbuf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
       if (us->data == MAP_FAILED)
         us->data = nullptr;
 #else
